@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## HTML Object - ~/lib/HTML/Object/DOM/Document.pm
-## Version v0.2.0
-## Copyright(c) 2021 DEGUEST Pte. Ltd.
+## Version v0.2.1
+## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/12/13
-## Modified 2022/09/18
+## Modified 2022/09/20
 ## All rights reserved
 ## 
 ## 
@@ -21,7 +21,7 @@ BEGIN
     use HTML::Object::ErrorEvent;
     use Scalar::Util ();
     use Want;
-    our $VERSION = 'v0.2.0';
+    our $VERSION = 'v0.2.1';
 };
 
 use strict;
@@ -840,7 +840,7 @@ sub title : lvalue
                     return( $dummy );
                 }
                 return( $self->error( $error ) ) if( want( 'LVALUE' ) );
-                rreturn( $self->error( $error ) );
+                Want::rreturn( $self->error( $error ) );
             }
             my $head = $head_results->first;
             $e = $self->createElement( 'title' );
@@ -860,7 +860,7 @@ sub title : lvalue
             return( $dummy );
         }
         return( $e->text( $arg ) ) if( want( 'LVALUE' ) );
-        rreturn;
+        Want::rreturn;
     }
     else
     {
@@ -872,7 +872,7 @@ sub title : lvalue
                 return( $dummy );
             }
             return( '' ) if( want( 'LVALUE' ) );
-            rreturn;
+            Want::rreturn;
         }
         return( $results->first->text );
     }
@@ -1000,7 +1000,7 @@ sub _set_get_on_signal : lvalue
                 return( $dummy );
             }
             return( $self->error({ message => $error, class => 'HTML::Object::TypeError' }) ) if( want( 'LVALUE' ) );
-            rreturn( $self->error({ message => $error, class => 'HTML::Object::TypeError' }) );
+            Want::rreturn( $self->error({ message => $error, class => 'HTML::Object::TypeError' }) );
         }
         foreach my $sig ( @$sigs )
         {
@@ -1022,7 +1022,7 @@ sub _set_get_on_signal : lvalue
     }
     my $dummy = 1;
     return( $dummy ) if( want( 'LVALUE' ) );
-    rreturn( $dummy );
+    Want::rreturn( $dummy );
 }
 
 1;
@@ -1043,7 +1043,7 @@ HTML::Object::DOM::Document - HTML Object DOM Document Class
 
 =head1 VERSION
 
-    v0.2.0
+    v0.2.1
 
 =head1 DESCRIPTION
 
