@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## HTML Object - ~/lib/HTML/Object/DOM/Element/Table.pm
-## Version v0.2.0
-## Copyright(c) 2021 DEGUEST Pte. Ltd.
+## Version v0.2.1
+## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/12/23
-## Modified 2022/09/18
+## Modified 2022/09/20
 ## All rights reserved
 ## 
 ## 
@@ -20,7 +20,7 @@ BEGIN
     use vars qw( $VERSION );
     use HTML::Object::DOM::Element::Shared qw( :table );
     use Want;
-    our $VERSION = 'v0.2.0';
+    our $VERSION = 'v0.2.1';
 };
 
 use strict;
@@ -528,7 +528,7 @@ sub _set_get_section : lvalue
                 return( $dummy );
             }
             return( $self->error({ message => $error, class => 'HTML::Object::HierarchyRequestError' }) ) if( want( 'LVALUE' ) );
-            rreturn( $self->error({ message => $error, class => 'HTML::Object::HierarchyRequestError' }) );
+            Want::rreturn( $self->error({ message => $error, class => 'HTML::Object::HierarchyRequestError' }) );
         }
         $new->detach;
         my( $old, $pos );
@@ -577,7 +577,7 @@ sub _set_get_section : lvalue
             my $dummy = '';
             return( $dummy ) if( $has_arg eq 'assign' );
             return( $old ) if( want( 'LVALUE' ) );
-            rreturn( $old );
+            Want::rreturn( $old );
         }
         else
         {
@@ -585,7 +585,7 @@ sub _set_get_section : lvalue
             my $dummy = '';
             return( $dummy ) if( $has_arg eq 'assign' );
             return if( want( 'LVALUE' ) );
-            rreturn;
+            Want::rreturn;
         }
     }
     else
@@ -613,7 +613,7 @@ HTML::Object::DOM::Element::Table - HTML Object DOM Table Class
 
 =head1 VERSION
 
-    v0.2.0
+    v0.2.1
 
 =head1 DESCRIPTION
 
