@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## HTML Object - ~/lib/HTML/Object/DOM/Element/Title.pm
-## Version v0.2.0
+## Version v0.2.1
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2022/01/09
-## Modified 2022/09/18
+## Modified 2022/09/20
 ## All rights reserved
 ## 
 ## 
@@ -19,7 +19,7 @@ BEGIN
     use parent qw( HTML::Object::DOM::Element );
     use vars qw( $VERSION );
     use Want;
-    our $VERSION = 'v0.2.0';
+    our $VERSION = 'v0.2.1';
 };
 
 use strict;
@@ -70,7 +70,7 @@ sub text : lvalue
                 return( $dummy );
             }
             return( $self->pass_error ) if( want( 'LVALUE' ) );
-            rreturn( $self->pass_error );
+            Want::rreturn( $self->pass_error );
         }
         my $ok = 1;
         for( @$nodes )
@@ -91,7 +91,7 @@ sub text : lvalue
                 return( $dummy );
             }
             return( $self->error( $error ) ) if( want( 'LVALUE' ) );
-            rreturn( $self->error( $error ) );
+            Want::rreturn( $self->error( $error ) );
         }
         $_->parent( $self ) for( @$nodes );
         my $children = $self->children;
@@ -140,7 +140,7 @@ sub text : lvalue
     }
     my $text = $self->{_title_text};
     return( $text ) if( want( 'LVALUE' ) );
-    rreturn( $text );
+    Want::rreturn( $text );
 }
 
 1;
@@ -161,7 +161,7 @@ HTML::Object::DOM::Element::Title - HTML Object DOM Title Class
 
 =head1 VERSION
 
-    v0.2.0
+    v0.2.1
 
 =head1 DESCRIPTION
 
